@@ -1,12 +1,15 @@
 package App::SmokeBox::Mini::Plugin::IRC;
+BEGIN {
+  $App::SmokeBox::Mini::Plugin::IRC::VERSION = '0.10';
+}
+
+#ABSTRACT: IRC plugin for minismokebox
 
 use strict;
 use warnings;
 use POE qw[Component::IRC Component::IRC::Plugin::Connector Component::IRC::Plugin::CTCP];
 use POE::Component::IRC::Common qw[u_irc];
 
-our $VERSION = '0.08';
-
 sub init {
   my $package = shift;
   my $config  = shift;
@@ -109,12 +112,18 @@ sub sbox_stop {
 
 qq[Smokey IRC];
 
+
 __END__
+=pod
 
 =head1 NAME
 
 App::SmokeBox::Mini::Plugin::IRC - IRC plugin for minismokebox
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   # example minismokebox configuration file
@@ -124,7 +133,6 @@ App::SmokeBox::Mini::Plugin::IRC - IRC plugin for minismokebox
   server = my.irc.server
   nick = mysmoker
 
-
 =head1 DESCRIPTION
 
 App::SmokeBox::Mini::Plugin::IRC is an IRC plugin for L<App::SmokeBox::Mini> and
@@ -137,6 +145,8 @@ When L<minismokebox> starts a bot will join configured channels and start announ
 completed smoke jobs. When the smoke run finishes the bot will announce statistics
 relating to the smoke run and then terminate.
 
+=for Pod::Coverage   ^irc|sbox|init
+
 =head1 CONFIGURATION
 
 This plugin uses an C<[IRC]> section within the L<minismokebox> configuration file.
@@ -175,20 +185,22 @@ A comma-separated list of IRC channels to join, default is C<#smokebox>
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<minismokebox>
 
 L<App::SmokeBox::Mini::Plugin>
 
+=head1 AUTHOR
+
+Chris Williams
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
